@@ -31,9 +31,13 @@
 #include <linux/kdev_t.h>	/* for MKDEV */
 #include <linux/major.h>	/* for LOOP_MAJOR */
 #endif
+#ifdef ENABLE_NLS
 #include <libintl.h>
 #include <locale.h>
 #define _(String) gettext (String)
+#else
+#define _(String) (String)
+#endif
 
 #include "comm.h"
 #include "loop.h"         /* for loop_info */
@@ -181,16 +185,6 @@ parse_net_file (SPACE_DSC * dsc,char *filename, NET_CACHE **lastptr,int version
 	  perror ("malloc");
 	  exit (1);
 	}
-      /*
-      if (sscanf (line, 
-#ifdef INO_T_IS_LONG_LONG
-        "%*d: %*x:%x %64[0-9A-Fa-f]:%x %*x %*x:%*x %*x:%*x %*x %*d %*d %Lu",
-#elif defined(INO_T_IS_INT)
-        "%*d: %*x:%x %64[0-9A-Fa-f]:%x %*x %*x:%*x %*x:%*x %*x %*d %*d %u",
-#else
-        "%*d: %*x:%x %64[0-9A-Fa-f]:%x %*x %*x:%*x %*x:%*x %*x %*d %*d %u",
-#endif
-        &new->lcl_port, rmt_addr, &new->rmt_port, &new->ino) != 4)*/
     if (sscanf (line, 
         "%*d: %*x:%x %64[0-9A-Fa-f]:%x %*x %*x:%*x %*x:%*x %*x %*d %*d %lu",
         &new->lcl_port, rmt_addr, &new->rmt_port, &tmp_ino) != 4)
@@ -206,7 +200,6 @@ parse_net_file (SPACE_DSC * dsc,char *filename, NET_CACHE **lastptr,int version
             &((struct sockaddr_in6 *)&new->rmt_addr)->sin6_addr.s6_addr32[2],
             &((struct sockaddr_in6 *)&new->rmt_addr)->sin6_addr.s6_addr32[3]);
         inet_ntop(AF_INET6, &((struct sockaddr_in6 *)&new->rmt_addr)->sin6_addr, addr6, sizeof(addr6));
-        /*printf("address %s\n", addr6);*/
       } else {
         sscanf(rmt_addr, "%X",
             &((struct sockaddr_in *) &new->rmt_addr)->sin_addr.s_addr);
@@ -316,7 +309,7 @@ fill_unix_cache (void)
 
 
 static unsigned long
-try_to_find_unix_dev (unsigned long inode)
+try_to_find_unix_dev (ino_t inode)
 {
   UNIX_CACHE *walk;
 
@@ -328,13 +321,13 @@ try_to_find_unix_dev (unsigned long inode)
 
 
 static void
-add_file (const char *path, unsigned long device, unsigned long inode,
+add_file (const char *path, dev_t device, ino_t inode,
 	  pid_t pid, int ref)
 {
   struct stat st;
   FILE_DSC *file, *next;
   ITEM_DSC **item, *this;
-  unsigned long mount_dev;
+  dev_t mount_dev;
 
   if (device)
     mount_dev = device;
@@ -378,8 +371,8 @@ add_file (const char *path, unsigned long device, unsigned long inode,
 
 
 static void
-add_other (ITEM_TYPE type, unsigned long mount_dev,
-	   unsigned long device, unsigned long inode, const char *path)
+add_other (ITEM_TYPE type, dev_t mount_dev,
+	   dev_t device, ino_t inode, const char *path)
 {
   FILE_DSC *file, *next;
   ITEM_DSC **item, *this;
@@ -429,16 +422,19 @@ check_map (const char *rel, pid_t pid, int type)
   FILE *file;
   char line[MAX_LINE + 1];
   int major, minor;
-  unsigned long inode;
+  ino_t inode;
+  unsigned long long tmp_inode;
 
   if (!(file = fopen (rel, "r")))
     return;
   while (fgets (line, MAX_LINE, file))
     {
-      if (sscanf (line, "%*s %*s %*s %x:%x %ld", &major, &minor, &inode) != 3)
+      if (sscanf (line, "%*s %*s %*s %x:%x %lld", &major, &minor, &tmp_inode) != 3)
 	continue;
-      if (major || minor || inode)
-	add_file (rel, MKDEV (major, minor), inode, pid, type);
+      if (major || minor || tmp_inode) {
+        inode = (ino_t)(tmp_inode);
+	    add_file (rel, MKDEV (major, minor), inode, pid, type);
+      }
     }
   fclose (file);
 }
@@ -663,31 +659,31 @@ show_files_or_kill (void)
       {
 	if (header && (file->flags & FLAG_VERB))
 	  {
-	    printf ("\n%*s USER        PID ACCESS COMMAND\n", NAME_FIELD, "");
+	    fprintf (stderr, "\n%*s USER        PID ACCESS COMMAND\n", NAME_FIELD, "");
 	    header = 0;
 	  }
 	length = 0;
 	for (scan = file->name; scan && *scan; scan++)
 	  if (*scan == '\\')
-	    length += printf ("\\\\");
+	    length += fprintf (stderr, "\\\\");
 	  else if (*scan > ' ' && *scan <= '~')
 	    {
-	      putchar (*scan);
+	      putc(*scan,stderr);
 	      length++;
 	    }
 	  else
-	    length += printf ("\\%03o", *scan);
+	    length += fprintf (stderr, "\\%03o", *scan);
 	if (file->name_space)
-	  length += printf ("/%s", file->name_space->name);
+	  length += fprintf (stderr, "/%s", file->name_space->name);
 
 	if (length > 0)
 	  last_namelen=length;
 	else
-	  printf("\n%*.*s",last_namelen,last_namelen," ");
+	  fprintf(stderr, "\n%*.*s",last_namelen,last_namelen," ");
 
 	if (!(file->flags & FLAG_VERB))
 	  {
-	    putchar (':');
+	    putc (':',stderr);
 	    length++;
 	  }
 
@@ -701,27 +697,28 @@ show_files_or_kill (void)
         if ((first==1) && (item->u.proc.ref_set & (REF_FILE|REF_ROOT|REF_CWD|REF_EXE|REF_MMAP))) {
     while (length < NAME_FIELD)
     {
-      putchar (' ');
+      putc(' ',stderr);
       length++;
     }
         }
-		if (item->u.proc.ref_set & REF_FILE)
-		  printf ("%6d", item->u.proc.pid);
+		printf ("%6d", item->u.proc.pid);
+        fflush(stdout);
+		/* if (item->u.proc.ref_set & REF_FILE)*/
 		if (item->u.proc.ref_set & REF_ROOT)
-		  printf ("%6dr", item->u.proc.pid);
+		  putc ('r', stderr);
 		if (item->u.proc.ref_set & REF_CWD)
-		  printf ("%6dc", item->u.proc.pid);
+		  putc ('c', stderr);
 		if (item->u.proc.ref_set & REF_EXE)
-		  printf ("%6de", item->u.proc.pid);
+		  putc ('e', stderr);
 		else if (item->u.proc.ref_set & REF_MMAP)
-		  printf ("%6dm", item->u.proc.pid);
+		  putc ('m', stderr);
 		if ((file->flags & FLAG_UID) && item->u.proc.uid !=
 		    UID_UNKNOWN)
                 {
 		  if ((pw = getpwuid (item->u.proc.uid)) != NULL) {
-		    printf ("(%s)", pw->pw_name);
+		    fprintf (stderr, "(%s)", pw->pw_name);
                   } else {
-		    printf ("(%d)", item->u.proc.uid);
+		    fprintf (stderr, "(%d)", item->u.proc.uid);
                   }
                 }
 		first = 0;
@@ -766,20 +763,22 @@ show_files_or_kill (void)
 		    user = tmp;
 		  }
 		if (!first)
-		  printf ("%*s", NAME_FIELD, "");
+		  fprintf (stderr, "%*s", NAME_FIELD, "");
 		else if (length > NAME_FIELD)
-		  printf ("\n%*s", NAME_FIELD, "");
+		  fprintf (stderr, "\n%*s", NAME_FIELD, "");
         else
           while (length < NAME_FIELD)
           {
-            putchar (' ');
+            putc(' ', stderr);
             length++;
           }
-		printf (" %-8s ", user);
+		fprintf (stderr, " %-8s ", user);
 		switch (item->type)
 		  {
 		  case it_proc:
-		    printf ("%6d %c%c%c%c%c  ", item->u.proc.pid,
+		    printf ("%6d", item->u.proc.pid);
+            fflush(stdout);
+            fprintf (stderr, " %c%c%c%c%c  ",
 			    item->u.proc.ref_set & REF_FILE ? 'f' : '.',
 			    item->u.proc.ref_set & REF_ROOT ? 'r' : '.',
 			    item->u.proc.ref_set & REF_CWD ? 'c' : '.',
@@ -788,31 +787,31 @@ show_files_or_kill (void)
 			    !(item->u.proc.ref_set & REF_EXE) ? 'm' : '.');
 		    break;
 		  case it_mount:
-		    printf (_("kernel mount  "));
+		    fprintf (stderr, _("kernel mount  "));
 		    break;
 		  case it_loop:
-		    printf (_("kernel loop   "));
+		    fprintf (stderr, _("kernel loop   "));
 		    break;
 		  case it_swap:
-		    printf (_("kernel swap   "));
+		    fprintf (stderr, _("kernel swap   "));
 		    break;
 		  }
 		if (name)
                 {
 		  for (scan = name; *scan; scan++)
 		    if (*scan == '\\')
-		      printf ("\\\\");
+		      fprintf (stderr, "\\\\");
 		    else if (*scan > ' ' && *scan <= '~')
-		      putchar (*scan);
+		      putc (*scan,stderr);
 		    else
-		      printf ("\\%03o", (unsigned char) *scan);
+		      fprintf (stderr, "\\%03o", (unsigned char) *scan);
                 }
-		putchar ('\n');
+		putc ('\n',stderr);
 	      }
 	    first = 0;
 	  }
 	if (!(file->flags & FLAG_VERB) || first)
-	  putchar ('\n');
+	  putc('\n',stderr);
 	if (file->flags & FLAG_KILL)
 	  for (item = file->items; item; item = item->next)
 	    kill_item (file, item);
@@ -889,7 +888,6 @@ parse_inet (const char *spec, const char *name_space, int *lcl_port,
   address_match = 0;
   for (here = s; here; here = next ? next + 1 : NULL)
     {
-      printf("here: %s\n", here);
       next = strchr (here, ',');
       if (next)
 	*next = 0;
@@ -960,11 +958,13 @@ static void
 usage (void)
 {
   fprintf (stderr, _(
-    "usage: fuser [ -a | -s ] [ -n space ] [ -signal ] [ -kimuv ] name ...\n"
+    "usage: fuser [ -a | -s | -c ] [ -n space ] [ -signal ] [ -kimuv ] name ...\n"
     "             [ - ] [ -n space ] [ -signal ] [ -kimuv ] name ...\n"
     "       fuser -l\n"
     "       fuser -V\n\n"
     "    -a        display unused files too\n"
+    "    -c        mounted FS\n"
+    "    -f        silently ignored (for POSIX compatibility\n"
     "    -k        kill processes accessing that file\n"
     "    -i        ask before killing (ignored without -k)\n"
     "    -l        list signal names\n"
@@ -1007,9 +1007,11 @@ main (int argc, char **argv)
   no_files = 1;
 
   /* Setup the i18n */
+#ifdef ENABLE_NLS
   setlocale(LC_ALL, "");
   bindtextdomain(PACKAGE, LOCALEDIR);
   textdomain(PACKAGE);
+#endif
 
   if (argc < 2)
     usage ();
@@ -1039,6 +1041,8 @@ main (int argc, char **argv)
 		case 'a':
 		  all = 1;
 		  break;
+        case 'f':
+          break;
 		case 'k':
 		  flags |= FLAG_KILL;
 		  do_kill = 1;
@@ -1047,6 +1051,7 @@ main (int argc, char **argv)
 		  flags |= FLAG_ASK;
 		  break;
 		case 'm':
+		case 'c':
 		  flags |= FLAG_DEV;
 		  break;
 		case 'n':
@@ -1178,7 +1183,7 @@ main (int argc, char **argv)
 		}
 	      for (walk = this_name_space->cache; walk; walk = walk->next)
 		if ((lcl_port == -1 || walk->lcl_port == lcl_port) &&
-		    (rmt_addr.ss_family = 0|| ( memcmp(
+		    (rmt_addr.ss_family == 0 || ( memcmp(
                      &((struct sockaddr_in6*)&walk->rmt_addr)->sin6_addr,
                      &((struct sockaddr_in6*)&rmt_addr)->sin6_addr,
                      sizeof(struct in6_addr)) == 0) ) &&
