@@ -11,6 +11,7 @@
 #endif
 
 #include <stdlib.h>
+#include <unistd.h>
 #include <stdio.h>
 #include <string.h>
 #include <unistd.h>
@@ -21,24 +22,28 @@
 #include <sys/stat.h>
 #include <getopt.h>
 #ifdef FLASK_LINUX
-#include <fs_secure.h>
-#include <ss.h>
+#include <selinux/fs_secure.h>
+#include <selinux/ss.h>
 #endif /*FLASK_LINUX*/
+#ifdef ENABLE_NLS
 #include <libintl.h>
 #include <locale.h>
 #define _(String) gettext (String)
+#else
+#define _(String) (String)
+#endif
 
 #include "comm.h"
 #include "signals.h"
 
 
 #define PROC_BASE "/proc"
-#define MAX_NAMES (sizeof(unsigned long)*8)
+#define MAX_NAMES (int)(sizeof(unsigned long)*8)
 
 
-static int verbose = 0, exact = 0, interactive = 0, quiet =
-  0, wait_until_dead = 0, process_group = 0, pidof;
-
+static int verbose = 0, exact = 0, interactive = 0,
+           quiet = 0, wait_until_dead = 0, process_group = 0,
+           ignore_case = 0, pidof;
 
 static int
 ask (char *name, pid_t pid)
@@ -131,7 +136,7 @@ kill_all (int signal, int names, char **namelist)
   pids = 0;
   while ( (de = readdir (dir)) != NULL)
     {
-      if (!(pid = atoi (de->d_name)) || pid == self)
+      if (!(pid = (pid_t) atoi (de->d_name)) || pid == self)
 	continue;
       if (pids == max_pids)
 	{
@@ -206,7 +211,8 @@ kill_all (int signal, int names, char **namelist)
 		{
 		  int cur_size = cmd_size;
 		  cmd_size *= 2;
-		  if (!realloc(&command_buf, cmd_size))
+		  command_buf = (char *)realloc(command_buf, cmd_size);
+		  if (!command_buf)
 		    exit (1);
 		  p = command_buf + cur_size;
 		}
@@ -248,8 +254,16 @@ kill_all (int signal, int names, char **namelist)
 	    {
 	      if (length != COMM_LEN - 1 || name_len[j] < COMM_LEN - 1)
 		{
-		  if (strcmp (namelist[j], comm))
+		  if (ignore_case == 1)
+		  {
+		    if (strcasecmp (namelist[j], comm))
 		    continue;
+		  }
+		  else
+		  {
+		    if (strcmp(namelist[j], comm))
+		    continue;
+		  }
 		}
 	      else if (got_long ? strcmp (namelist[j], command) :
 		       strncmp (namelist[j], comm, COMM_LEN - 1))
@@ -268,17 +282,22 @@ kill_all (int signal, int names, char **namelist)
 	      if (asprintf (&path, PROC_BASE "/%d/exe", pid_table[i]) < 0)
 		continue;
 #ifdef FLASK_LINUX
-              if (stat_secure(path,&st,&lsid) < 0) continue;
-              if (sts[j].st_dev != st.st_dev ||
-                  sts[j].st_ino != st.st_ino ||
-                  ((int) sid > 0 && (lsid != sid)) )
-                  continue;
+          if (stat_secure(path,&st,&lsid) < 0) {
+            free(path);
+            continue;
+          }
+          if (sts[j].st_dev != st.st_dev ||
+              sts[j].st_ino != st.st_ino ||
+              ((int) sid > 0 && (lsid != sid)) ) {
+            free(path);
+            continue;
+          }
 #else  /*FLASK_LINUX*/
 	      if (stat (path, &st) < 0) {
-		free (path);
-		continue;
-#endif /*FLASK_LINUX*/
+		    free (path);
+		    continue;
 	      }
+#endif /*FLASK_LINUX*/
 	      free (path);
 
 	      if (sts[j].st_dev != st.st_dev || sts[j].st_ino != st.st_ino)
@@ -384,6 +403,7 @@ usage_killall (void)
   fprintf (stderr, "       killall -l, --list\n");
   fprintf (stderr, "       killall -V --version\n\n");
   fprintf (stderr, "  -e,--exact          require exact match for very long names\n");
+  fprintf (stderr, "  -I,--ignore-case-   case insensitive process name match\n");
   fprintf (stderr, "  -g,--process-group  kill process group instead of process\n");
   fprintf (stderr, "  -i,--interactive    ask for confirmation before killing\n");
   fprintf (stderr, "  -l,--list           list all known signal names\n");
@@ -393,10 +413,9 @@ usage_killall (void)
   fprintf (stderr, "  -V,--version        display version information\n");
   fprintf (stderr, "  -w,--wait           wait for processes to die\n\n");
 #ifdef FLASK_LINUX
-  fprintf (stderr, "  -S,--Sid            kill only process(es) having sid\n");
+  fprintf (stderr, "  -d,--sid            kill only process(es) having sid\n");
   fprintf (stderr, "  -c,--context        kill only process(es) having scontext\n");
-  fprintf(stderr, "   (-s, -c are mutually exclusive and must precede other
-arguments)\n\n");
+  fprintf(stderr, "   (-s, -c are mutually exclusive and must precede other arguments)\n\n");
 #endif /*FLASK_LINUX*/
 }
 
@@ -432,6 +451,7 @@ main (int argc, char **argv)
 
   struct option options[] = {
     {"exact", 0, NULL, 'e'},
+    {"ignore-case", 0, NULL, 'I'},
     {"process-group", 0, NULL, 'g'},
     {"interactive", 0, NULL, 'i'},
     {"list-signals", 0, NULL, 'l'},
@@ -440,7 +460,7 @@ main (int argc, char **argv)
     {"verbose", 0, NULL, 'v'},
     {"wait", 0, NULL, 'w'},
 #ifdef FLASK_LINUX
-    {"Sid", 1, NULL, 'S'},
+    {"Sid", 1, NULL, 'd'},
     {"context", 1, NULL, 'c'},
 #endif /*FLASK_LINUX*/
     {"version", 0, NULL, 'V'},
@@ -461,12 +481,18 @@ main (int argc, char **argv)
   sig_num = SIGTERM;
 
   /* Setup the i18n */
+#ifdef ENABLE_NLS
   setlocale(LC_ALL, "");
   bindtextdomain(PACKAGE, LOCALEDIR);
   textdomain(PACKAGE);
+#endif
 
   opterr = 0;
-  while ( (optc = getopt_long_only(argc,argv,"egilqs:vwS:c:V",options,NULL)) != EOF) {
+#ifdef FLASK_LINUX
+  while ( (optc = getopt_long_only(argc,argv,"egilqs:vwd:c:VI",options,NULL)) != EOF) {
+#else
+  while ( (optc = getopt_long_only(argc,argv,"egilqs:vwVI",options,NULL)) != EOF) {
+#endif
     switch (optc) {
       case 'e':
         exact = 1;
@@ -503,14 +529,18 @@ main (int argc, char **argv)
           usage();
         wait_until_dead = 1;
         break;
+      case 'I':
+        ignore_case = 1;
+        break;
       case 'V':
         print_version();
         return 0;
         break;
 #ifdef FLASK_LINUX
-      case 'S': {
+      case 'd': {
           char **buf, *calloc();
           int strlen(), rv;
+          __u32 len;
           security_id_t lsid;
 
           buf = (char **) calloc(1, strlen(optarg));
@@ -528,7 +558,8 @@ main (int argc, char **argv)
 
           sid = (security_id_t) lsid;
           /* sanity check */
-          rv = security_sid_to_context(sid, buf, strlen(optarg));
+          len = strlen(optarg);
+          rv = security_sid_to_context(sid, buf, &len);
           if ( rv < 0 && (errno != ENOSPC) ) {
               (void) fprintf(stderr, "%s: security_sid_to_context(%d) %s\n", name, (int) sid, strerror(errno));
               (void) fflush(stderr);
